<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:map="http://www.w3.org/2005/xpath-functions/map" exclude-result-prefixes="xs" version="3.0">
	<xsl:output method="xml" indent="no"/>
	<xsl:mode on-no-match="shallow-copy"/>
	<!--
  Skript zur Erstellung der Rhodoman-Statistiken mit XML-Output.
  Anzuwenden auf die Eingabedatei analysisBaseCombinedXML.xml, die Projektdaten im standardisierten, reduzierten Format enthält.
  Ziel: Generierung einer Div-Struktur (mit Listen und z.T. Tabellen) mit berechneten Werten und Freitextbeschreibungen der Analysen.
  
  Aufbau:
  - Globale Variablen:
      einfache, ggf. wiederverwertbare berechnete Werte
  - Div-Struktur:
      natürlichsprachliche Beschreibungen der Berechnungen; ruft die Berechnungstemplates auf.
  - Berechnungstemplates:
      1. Wiederverwendbare Pattern-Templates (mit einfachen Parametern für allgemeine Berechnungen)
      2. Individuelle, komplexe Berechnungstemplates (für spezifische Auswertungen, die nicht erneut verwendet werden)
-->
	<!--............................................................................................................................................................................-->
	<!-- globale Variablen (für einfache, ggf. wiederverwertbare Werte) -->
	<!--............................................................................................................................................................................-->
	<xsl:variable name="result" select="doc('analysisBaseCombinedXML.xml')"/>
	<xsl:variable name="countTEI" select="count($result//tei:TEI)"/>
	<xsl:variable name="countDivSegment" select="count($result//tei:div[@type = 'segment'])"/>
	<xsl:variable name="countL" select="count($result//tei:div[@type = 'transcript']//tei:l)"/>
	<xsl:variable name="countLgL" select="count($result//tei:lg/tei:l)"/>
	<xsl:variable name="countHeadL" select="count($result//tei:head/tei:l)"/>
	<xsl:variable name="countOpenerL" select="count($result//tei:opener/tei:l)"/>
	<xsl:variable name="countCloserL" select="count($result//tei:closer/tei:l)"/>
	<xsl:variable name="countAbL" select="count($result//tei:ab/tei:l)"/>
	<xsl:variable name="countLgLSeg" select="count($result//tei:lg/tei:l/tei:seg[@xml:lang[matches(., 'la') or matches(., 'grc')] and not(@function) and not(@type = 'marginalia')])"/>
	<xsl:variable name="countLSegForeign" select="count($result//tei:l/tei:seg[not(@function) and not(@type = 'marginalia') and descendant::tei:foreign])"/>
	<xsl:variable name="countLgLDistinct" select="count($result//tei:lg/tei:l//tei:distinct)"/>
	<xsl:variable name="countLgLMono" select="count($result//tei:lg/tei:l//tei:seg[@type = 'monosyllabum'])"/>
	<xsl:variable name="countLgLSpon" select="count($result//tei:lg/tei:l//tei:seg[@type = 'spondaic'])"/>
	<xsl:variable name="countLgLVersusTetracoli" select="count($result//tei:lg/tei:l[contains(@ana, '#versusTetracoli')])"/>
	<xsl:variable name="countNoteRefSimExt" select="count($result//tei:note[@type = 'similia']//tei:ref[@type = 'external' and @subtype = 'similia'])"/>
	<xsl:variable name="countNoteRefSimInt" select="count($result//tei:note[@type = 'similia']//tei:ref[@type = 'internal' and @subtype = 'similia'])"/>
	<xsl:variable name="distValsGattung" as="xs:string*" select="sort(distinct-values($result//tei:textClass[@type = 'literaryGenre']//tei:term[string()]))"/>
	<xsl:variable name="distValsSchaffensphase" as="xs:string*" select="sort(distinct-values($result//tei:textClass[@type = 'creativePeriod']//tei:term[string()]))"/>
	<xsl:variable name="distValsMetCaesura" as="xs:string*" select="('metCaesuraPHGrc', 'metCaesuraKTTGrc', 'metCaesuraOtherGrc', 'metCaesuraPHLat', 'metCaesuraKTTLat', 'metCaesuraOtherLat')"/>
	<xsl:variable name="distValsHexameterGrc" select="sort(distinct-values($result//tei:back//tei:item[@type = 'metMetricalFootGrc']/tei:num[@type = 'numGroup']/@n))"/>
	<xsl:variable name="distValsHexameterLat" select="sort(distinct-values($result//tei:back//tei:item[@type = 'metMetricalFootLat']/tei:num[@type = 'numGroup']/@n))"/>
	<!--NB: sort() um distinct-Values bereits hier alph. zu sortieren-->
	<!--............................................................................................................................................................................-->
	<!-- Ausgabe Div-Struktur -->
	<!--............................................................................................................................................................................-->
	<xsl:template match="tei:revisionDesc/tei:change/@when">
		<xsl:attribute name="when">
			<xsl:value-of select="format-date(current-date(), '[Y0001]-[M01]-[D01]')"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="tei:text/tei:body/tei:div">
		<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
			<xsl:copy-of select="@*"/>
			<!--.................................................................................-->
			<!--Allgemeines-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Allgemeines'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Allgemeines</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Bearbeitungsstand (nur veröffentlichte Einheiten)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Eine Einheit (TEI) ist ein Werk Rhodomans mit individuellem Projektkürzel. Sie umfasst ein oder mehrere Einzelgedichte (div) inklusive Titel, Incipit etc. Berücksichtigt werden nur Einheiten, bei denen mindestens die Metadaten online zur Verfügung stehen. Angegeben wird die Anzahl der Einheiten (TEI) bzw. der Gedichte (div).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Einheiten (TEI) insg.'"/>
							<xsl:value-of select="$countTEI"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Einheiten (TEI) ediert'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a001'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Einheiten (TEI) unediert'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a003'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Einzelgedichte (div)'"/>
							<xsl:value-of select="$countDivSegment"/>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Dokumenttypen</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Dokumenttypen sind: Manuskript (manuscript), Druck (print) oder Inschrift (epigraphicInscription). Angegeben wird die Anzahl der Einheiten (TEI).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Typ Manuskript (manuscript)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a004'"/>
								<xsl:with-param name="p-type" select="'manuscript'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Typ Druck (print)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a004'"/>
								<xsl:with-param name="p-type" select="'print'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Typ Inschrift (epigraphicInscription)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a004'"/>
								<xsl:with-param name="p-type" select="'epigraphicInscription'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Gedicht/Brief</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Einheiten sind entweder Briefe (letter) oder Gedichte (!letter = nicht letter). Angegeben wird die Anzahl der Einheiten (TEI).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Typ Gedicht (!letter)'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a008'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Typ Brief (letter)'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a007'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Verse (l)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Verse (l) bestehen aus einer lateinischen und/oder griechischen Fassung (seg) sowie einer editorischen deutschen Übersetzung (dt). Untersucht werden Verse in Gedichttexten (lg), Titel (head), Incipt (opener), Explicit (closer) oder Prosa (ab). Angegeben werden die Anzahl der Verse (l) oder die Gedichtkürzel.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse insg.'"/>
							<xsl:value-of select="$countL"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (lg)'"/>
							<xsl:value-of select="$countLgL"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (head)'"/>
							<xsl:value-of select="$countHeadL"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (opener)'"/>
							<xsl:value-of select="$countOpenerL"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (closer)'"/>
							<xsl:value-of select="$countCloserL"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (ab)'"/>
							<xsl:value-of select="$countAbL"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse nur Gr. (lg)'"/>
							<xsl:call-template name="a011">
								<xsl:with-param name="p-lang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse nur Lat. (lg)'"/>
							<xsl:call-template name="a011">
								<xsl:with-param name="p-lang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse Gr.+Lat. (lg)'"/>
							<xsl:call-template name="a011">
								<xsl:with-param name="p-lang" select="'grc-la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'längstes Gedicht (lg)'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'div'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'1'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'kürzestes Gedicht (lg)'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'div'"/>
								<xsl:with-param name="p-minmax" select="'min'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'1'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Sprachsegmente-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Sprachsegmente'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Sprachsegmente</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Sprachsegmente Gr./Lat. (lg//seg[!marginalia])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Sprachsegmente (seg) bezeichnen die jeweils lateinische oder griechische Fassung eines Verses. Untersucht werden nur Sprachsegmente in Gedichttexten (lg). Marginalien werden nicht berücksichtigt (!marginalia). Unterschieden werden die Sprachen Griechisch (Gr.), Griechisch-Dorisch (Gr.(Dor.)) und Latein (Lat.). Angegeben wird die Anzahl der Sprachsegmente (seg).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente insg.'"/>
							<xsl:value-of select="$countLgLSeg"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr.'"/>
							<xsl:call-template name="pattern-countLang">
								<xsl:with-param name="p-countVar" select="'a012'"/>
								<xsl:with-param name="p-lang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr.(Dor.)'"/>
							<xsl:call-template name="pattern-countLang">
								<xsl:with-param name="p-countVar" select="'a012'"/>
								<xsl:with-param name="p-lang" select="'grc-dor'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Lat.'"/>
							<xsl:call-template name="pattern-countLang">
								<xsl:with-param name="p-countVar" select="'a012'"/>
								<xsl:with-param name="p-lang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Sprachsegmente mit fremdspr. Einsprengseln (seg[!marginalia]/foreign)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Fremdsprachige Einsprengsel (foreign) bezeichnen lateinische Wörter in einem sonst griechischen Sprachsegment (seg) bzw. umgekehrt. Untersucht werden die Sprachsegmente innerhalb von Gedichttexten (lg), Titel (head), Explicit (closer), Incipit (opener) und Prosa (ab). Marginalien werden nicht berücksichtigt (!marginalia). Angegeben wird die Anzahl der Sprachsegmente (seg).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente mit Einsprengseln insg.'"/>
							<xsl:value-of select="$countLSegForeign"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr. mit lat. Einsprengseln (in lg)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'lg'"/>
								<xsl:with-param name="p-foreignLang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr. mit lat. Einsprengseln (in head)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'head'"/>
								<xsl:with-param name="p-foreignLang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr. mit lat. Einsprengseln (in closer)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'closer'"/>
								<xsl:with-param name="p-foreignLang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr. mit lat. Einsprengseln (in opener)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'opener'"/>
								<xsl:with-param name="p-foreignLang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Gr. mit lat. Einsprengseln (in ab)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'ab'"/>
								<xsl:with-param name="p-foreignLang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Lat. mit gr. Einsprengseln (in lg)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'lg'"/>
								<xsl:with-param name="p-foreignLang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Lat. mit gr. Einsprengseln (in head)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'head'"/>
								<xsl:with-param name="p-foreignLang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Lat. mit gr. Einsprengseln (in closer)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'closer'"/>
								<xsl:with-param name="p-foreignLang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Lat. mit gr. Einsprengseln (in opener)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'opener'"/>
								<xsl:with-param name="p-foreignLang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachsegmente Lat. mit gr. Einsprengseln (in ab)'"/>
							<xsl:call-template name="a013">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'ab'"/>
								<xsl:with-param name="p-foreignLang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Marginalien-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Marginalien'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Marginalien</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Marginalien (lg//marginalia)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text><!--TODO--></xsl:text>
						<!--<xsl:text>Marginalien (marginalia) sind Segmente (seg) neben den gr. und lat. Sprachsegmenten. Pro Vers (l) kann es optional eine bis maximal zwei Marginalien geben. Marginalien in zweisprachigen Gedichten beziehen sich entweder nur auf das primäre oder sekundäre Sprachsegment (@subtype='mainText|translationOfMainText') oder auf beide (@subtype='all'). Das primäre/sekundäre Sprachsegment kann entweder Lat. oder Gr. sein. In einsprachigen Gedichten (lat. oder gr.) ist immer @subtype='all' gesetzt. Die Marginaliensprache (@xml:lang) kann von der Sprache des zugehörigen Sprachsegments abweichen (z.B. eine lat. Marginalie zu einem gr. Gedicht). Ausgegeben wird die Anzahl der Marginalien (margainalia).</xsl:text>-->
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien ges. (marginalia)'"/>
							<xsl:call-template name="a014">
								<xsl:with-param name="p-count" select="'seg'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (l) mit Marginalien'"/>
							<xsl:call-template name="a014">
								<xsl:with-param name="p-count" select="'l'"/>
							</xsl:call-template>
						</xsl:element>
						<!--TEMP: ausgeklammert, weil Kodierung nicht klar. -->
						<!--<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien zum Gr. (einsprachig)'"/>
							<xsl:call-template name="a015">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'single'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien zum Lat. (einsprachig)'"/>
							<xsl:call-template name="a015">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'single'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien nur zum Gr. (zweisprachig)'"/>
							<xsl:call-template name="a015">
								<xsl:with-param name="p-lang" select="'grc'"/>
								<xsl:with-param name="p-seg" select="'double'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien nur zum Lat. (zweisprachig)'"/>
							<xsl:call-template name="a015">
								<xsl:with-param name="p-lang" select="'la'"/>
								<xsl:with-param name="p-seg" select="'double'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien zum Gr. und Lat. (zweisprachig)'"/>
							<xsl:call-template name="a015">
								<xsl:with-param name="p-lang" select="'grc+la'"/>
								<xsl:with-param name="p-seg" select="'double'"/>
							</xsl:call-template>
						</xsl:element>-->
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien auf Gr. (nicht zwangsl. zum gr. seg gehörend)'"/>
							<xsl:call-template name="pattern-countLang">
								<xsl:with-param name="p-countVar" select="'a016'"/>
								<xsl:with-param name="p-lang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Marginalien Lat. (nicht zwangsl. zum lat. seg gehörend)'"/>
							<xsl:call-template name="pattern-countLang">
								<xsl:with-param name="p-countVar" select="'a016'"/>
								<xsl:with-param name="p-lang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Neologismen-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Neologismen'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Neologismen</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zum <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-neologismen.html'"/>Neologismenregister</xsl:element></xsl:element>
				
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Neologismen (lg//distinct)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Als Neologismen (distinct) ausgezeichnet sind Wörter, die nicht in den angeführten Lexika (LSJ 1996, Lampe 1961, LBG 2017) enthalten sind. Neologismen werden nur innerhalb von Gedichttexten (lg) untersucht. In einem Vers (l) können mehrere Neologismen auftreten (innerhalb desselben Sprachsegements oder sowohl im Gr. als auch im Lat.). Angegeben werden die 10 Gedichte (div) mit den höchsten Werten a) absolut und b) im Verhältnis zur Gesamtversanzahl des Gedichts.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Neologismen ges.'"/>
							<xsl:value-of select="$countLgLDistinct"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachverteilung'"/>
							<xsl:call-template name="a019">
								<xsl:with-param name="p-type" select="'distinct'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (absolut) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'distinct'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (im Verhältnis zur Verszahl (l)) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'distinct'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'ratio'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--.................................................................................-->
			<!--Similien-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Similien'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Similien</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zum <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-similien.html'"/>Similienregister</xsl:element></xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Similien (Zitate) im Text (lg//quote)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Similien bezeichnen a) die Zitate im Text (quote) und b) die Autorenstellen in den Anmerkungen (similia). Berücksichtigt werden nur Zitate in den Gedichttexten (lg). Die zitierten Textstellen sind entweder vollständig (complete), vollständig über mehrere Verse hinweg (range) oder fragmentiert (fragmented). Bei range und fragmented wird jeweils nur der erste Teil gezählt (rangeStart|fragmentedStart), da die weiteren Bestandteile semantisch zum selben Zitat gehören. Angegeben wird die Anzahl der Zitate (quote).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Similien im Text ges. [complete|fragmentedStart|rangeStart]'"/>
							<!--bei range+fragmented wird jew. nur der erste Teil gezählt, nicht alle Teile einzeln (z.B. "rangeMiddle"), weil sie semantisch als ein quote zusammengehören-->
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a017'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'vollständige Stelle (complete)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a018'"/>
								<xsl:with-param name="p-type" select="'complete'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'lange/mehrzeilige Stelle (rangeStart)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a018'"/>
								<xsl:with-param name="p-type" select="'rangeStart'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'fragmentierte Stelle (fragmentedStart)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a018'"/>
								<xsl:with-param name="p-type" select="'fragmentedStart'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Similien (Autorenstellen) in Anm. (back/list//similia)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Similien bezeichnen a) die Zitate im Text (quote) und b) die Autorenstellen in den Anmerkungen (similia). Autorenstellen sind entweder klassische Autoren (= extern) oder Rhodomans eigene Texte (= intern). Zu einem Zitat kann es eine oder mehrere Autorenstellen geben. Angegeben wird die Anzahl der Autorenstellen (similia), bzw. die 10 Gedichte (div=list) mit den höchsten Werten a) absolut und b) im Verhältnis zur Gesamtversanzahl des Gedichts.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Similien-Referenzen ges.'"/>
							<xsl:value-of select="$countNoteRefSimExt + $countNoteRefSimInt"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'auf ext. Autoren (= ext.)'"/>
							<xsl:value-of select="$countNoteRefSimExt"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'auf Rhod.-Texte (= int.)'"/>
							<xsl:value-of select="$countNoteRefSimInt"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten Referenzen auf ext. Autoren (= ext.) absolut (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'similia'"/>
								<xsl:with-param name="p-subtype" select="'external'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten Referenzen auf Rhod.-Texte (= int.) absolut (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'similia'"/>
								<xsl:with-param name="p-subtype" select="'internal'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten Referenzen auf ext. Autoren (= ext.) im Verhältnis zur Verszahl (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'similia'"/>
								<xsl:with-param name="p-subtype" select="'external'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'ratio'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten Referenzen auf Rhod.-Texte (= int.) im Verhältnis zur Verszahl (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'similia'"/>
								<xsl:with-param name="p-subtype" select="'internal'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'ratio'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Zitiergenauigkeit der Autorenstellen (back//similia/seg[simQualifier])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Die Zitiergenauigkeit identifiziert ein Zitat als: wörtlich (eq), ähnlich (sim), vergleiche (cf), zur Sache vergleiche (de_re_cf) oder nicht präzisiert (undefined). Untersucht werden interne (int.) und externe (ext.) Autorenstellen. Angegeben werden die Autorenstellen (similia) der jeweiligen Zitiergenauigkeit.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit cf. (cf) (ext.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'external'"/>
								<xsl:with-param name="p-qualifier" select="'cf'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit cf. (cf) (int.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'internal'"/>
								<xsl:with-param name="p-qualifier" select="'cf'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit = (eq) (ext.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'external'"/>
								<xsl:with-param name="p-qualifier" select="'eq'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit = (eq) (int.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'internal'"/>
								<xsl:with-param name="p-qualifier" select="'eq'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit ~ (sim) (ext.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'external'"/>
								<xsl:with-param name="p-qualifier" select="'sim'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit ~ (sim) (int.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'internal'"/>
								<xsl:with-param name="p-qualifier" select="'sim'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit de re cf. (de_re_cf) (ext.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'external'"/>
								<xsl:with-param name="p-qualifier" select="'de_re_cf'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit de re cf. (de_re_cf) (int.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'internal'"/>
								<xsl:with-param name="p-qualifier" select="'de_re_cf'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit undefined (undefined) (ext.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'external'"/>
								<xsl:with-param name="p-qualifier" select="'undefined'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitiergenauigkeit undefined (undefined) (int.)'"/>
							<xsl:call-template name="a022">
								<xsl:with-param name="p-intExt" select="'internal'"/>
								<xsl:with-param name="p-qualifier" select="'undefined'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Zitierte Autoren (ext.) (similia[external]/seg[simAuthor|simAuthorSingle|simTitle])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Zitierte klassische Autoren (ext.) in Autorenstellen (similia[external]) mit Autornennung: Berücksichtigt werden Autorenstellen, die entweder nur durch ein Autorkürzel (simAuthorSingle) oder durch ein Autorkürzel (simAuthor) und ein Werkkürzel (simTitle) identifiziert werden. Angegeben werden die standardisierten Autor- bzw. Werkkürzel.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitierte (versch.) Autoren (simAuthor|simAuthorSingle)'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a023'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'am häufigsten zitierte Autoren (simAuthor|simAuthorSingle) (Top 10)'"/>
							<xsl:call-template name="a024">
								<xsl:with-param name="p-type" select="'simAuthor'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'am häufigsten zitierte Autor-Werk-Kombination (simAuthor+simTitle) (Top 10)'"/>
							<xsl:call-template name="a024">
								<xsl:with-param name="p-type" select="'simAuthorTitle'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Zitierte alleinstehende Werke (ext.) (similia[external]/seg[simTitleSingle])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Zitierte klassische Autoren (ext.) in Autorenstellen (similia[external]) ohne Autornennung: Berücksichtigt werden Autorenstellen, die nur durch ein Werkkürzel (simTitleSingle) identifiziert werden. Angegeben werden die standardisierten Werkkürzel.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitierte (versch.) Titel (simTitleSingle)'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a025'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'am häufigsten zitierte Titel (Top 10)'"/>
							<xsl:call-template name="a024">
								<xsl:with-param name="p-type" select="'simTitle'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Zitierte Rhodomanwerke (int.) (similia[internal])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Zitierte Rhodomanwerke (int.) in Autorenstellen (similia[internal]). Berücksichtigt und angegeben werden Einheiten (TEI), Einzelgedichte (div=list) oder Autorenstellen (similia).</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitierte Rhodoman-Einheiten (TEI)'"/>
							<xsl:call-template name="a039">
								<xsl:with-param name="p-type" select="'target'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Zitierte Rhodoman-Einzelgedichte (div)'"/>
							<xsl:call-template name="a039">
								<xsl:with-param name="p-type" select="'sameAs'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Referenzen auf Textstellen innerhalb derselben Einheit (similia)'"/>
							<xsl:call-template name="a040">
								<xsl:with-param name="p-intExt" select="'int'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Referenzen auf Textstellen in anderen Einheiten (similia)'"/>
							<xsl:call-template name="a040">
								<xsl:with-param name="p-intExt" select="'ext'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'am häufigsten zitierte Rhodoman-Einheiten (Top 10) (TEI)'"/>
							<xsl:call-template name="a039">
								<xsl:with-param name="p-type" select="'target'"/>
								<xsl:with-param name="p-minMax" select="'true'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'am häufigsten zitierte Rhodoman-Einzelgedichte (Top 10) (div)'"/>
							<xsl:call-template name="a039">
								<xsl:with-param name="p-type" select="'sameAs'"/>
								<xsl:with-param name="p-minMax" select="'true'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Gattungen-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Gattungen'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Gattungen</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zur <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'werke-gattung.html'"/>Werkeübersicht (nach Gattungen)</xsl:element></xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Statistiken pro Gattung</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Gattungen bezeichnen editorisch identifizierte Textgattungen. Da die Gattungen pro Einheit (TEI) ausgezeichnet sind, nicht pro Gedicht (div), und eine Einheit mehreren Textgattungen angehören kann, ist eine Mehrfach- bzw. eine unpräzise Zuordnung möglich. Zu jeder Gattung werden Angaben über Werke gemacht, die dieser Gattung zugerechnet werden. Darunter die Anzahl der Gedichte, die höchste/niedrigste Verszahl, Neologismen, Monosyllaba, Marginalien etc.</xsl:text>
					</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Achtung: Mehrfach- bzw. unpräzise Zuordnung möglich, da Gattungen pro Einheit ausgezeichnet sind, nicht pro Einzelgedicht</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="hi" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="rend" select="'italic'"/>a) Einheiten (TEI) --- b) Gedichte (div) pro Sprachverteilung (Gr.|Lat.|Gr.+Lat.) --- c) Versanzahl längstes/kürzestes Gedicht (div/lg/l) --- d) Versanzahl ges. (lg/l) --- e) Neologismen (lg//distinct) --- f) Monosyllaba (lg//monosyllabum) --- g) Spondiaci (lg//spondaic) --- h) Versus tetracoli (lg/vt) --- i) Similien (lg//quote[complete|fragmStart|rangeStart]) --- j) Marginalien (lg//marginalia) --- k) Indexreferenzen (lg//seg[!de]/rs)</xsl:element>
					</xsl:element>
					<xsl:element name="table" namespace="http://www.tei-c.org/ns/1.0">
						<!--table-head-->
						<xsl:element name="row" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>Gattung</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>a)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>b)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>c)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>d)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>e)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>f)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>g)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>h)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>i)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>j)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>k)</xsl:element>
						</xsl:element>
						<!--table-body-->
						<!--rows/cells werden im Template selbst generiert-->
						<xsl:call-template name="a028-t">
							<xsl:with-param name="p-type" select="'literaryGenre'"/>
						</xsl:call-template>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Schaffensphasen-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Schaffensphasen'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Schaffensphasen</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zur <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'werke-chronologie.html'"/>Werkeübersicht (nach Schaffensphasen)</xsl:element></xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Statistiken pro Schaffensphase</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Schaffensphasen bezeichnen editorisch identifizierte Zeiträume, in denen Rhodoman primär an einem Ort tätig war. Zu jeder Schaffensphase werden Angaben über Werke gemacht, die in dieser Zeit entstanden sind. Darunter die Anzahl der Gedichte, die höchste/niedrigste Verszahl, Neologismen, Monosyllaba, Marginalien etc.</xsl:text>
					</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="hi" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="rend" select="'italic'"/>a) Einheiten (TEI) --- b) Gedichte (div) pro Sprachverteilung (Gr.|Lat.|Gr.+Lat.) --- c) Versanzahl längstes/kürzestes Gedicht (div/lg/l) --- d) Versanzahl ges. (lg/l) --- e) Neologismen (lg//distinct) --- f) Monosyllaba (lg//monosyllabum) --- g) Spondiaci (lg//spondaic) --- h) Versus tetracoli (lg/vt) --- i) Similien (lg//quote[complete|fragmStart|rangeStart]) --- j) Marginalien (lg//marginalia) --- k) Indexreferenzen (lg//seg[!de]/rs)</xsl:element>
					</xsl:element>
					<xsl:element name="table" namespace="http://www.tei-c.org/ns/1.0">
						<!--table-head-->
						<xsl:element name="row" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>Schaffensphase</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>a)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>b)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>c)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>d)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>e)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>f)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>g)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>h)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>i)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>j)</xsl:element>
							<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="role" select="'label'"/>k)</xsl:element>
						</xsl:element>
						<!--table-body-->
						<!--rows/cells werden im Template selbst generiert-->
						<xsl:call-template name="a028-t">
							<xsl:with-param name="p-type" select="'creativePeriod'"/>
						</xsl:call-template>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Indexreferenzen-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Indexreferenzen'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Indexreferenzen</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zum <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-personen.html'"/>Personenregister</xsl:element>, <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-orte.html'"/>Ortsregister</xsl:element>, <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-sach.html'"/>Sachregister</xsl:element></xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Am häufigsten referenzierte Indexeinträge (Top 10) [lat/gr; !dt !marginalia]</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Indexreferenzen (rs) bezeichnen Entitäten (Personen, Orte, Sachverhalte). Berücksichtigt werden sie im Text (1. in Gedichttexten (lg), 2. in Titel, Incipit, Explicit (head|opener|closer), 3. in Prosa (ab)) sowie in den Metadaten (teiHeader) und der editorischen Einführung (front). Bei mehrsprachigen Gedichten sind Indexreferenzen in jeder Sprache einzeln ausgezeichnet und werden entsprechend doppelt gezählt. Indexreferenzen in der deutschen Übersetzung und in Marginalien werden nicht berücksichtigt (!dt !marginalia). Angegeben werden die Register-IDs.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'im Text (lg)'"/>
							<xsl:call-template name="a029">
								<xsl:with-param name="p-parent" select="'lg'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'im Text (head/opener/closer)'"/>
							<xsl:call-template name="a029">
								<xsl:with-param name="p-parent" select="'hoc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'im Text [Prosa] (ab)'"/>
							<xsl:call-template name="a029">
								<xsl:with-param name="p-parent" select="'ab'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'in Metadaten (teiHeader)'"/>
							<xsl:call-template name="a029">
								<xsl:with-param name="p-parent" select="'teiHeader'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'in Metadaten [Einführung] (front)'"/>
							<xsl:call-template name="a029">
								<xsl:with-param name="p-parent" select="'front'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Beziehungen (vollst.) (teiHeader//rs)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Beziehungen bezeichnen editorisch erstellte Indexreferenzen (rs) in den Metadaten (teiHeader) auf Personen oder Orte, z.B. Widmungsempfänger (dedication), Drucker (publisher) oder sonstige Personenbezüge (note[relatedPersons]) bzw. Ortsbezüge (note[relatedPlaces]). Angegeben werden die Register-IDs.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Widmungsempfänger (dedication)'"/>
							<xsl:call-template name="a037">
								<xsl:with-param name="p-type" select="'dedication'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Personenbezüge (note[relatedPersons])'"/>
							<xsl:call-template name="a037">
								<xsl:with-param name="p-type" select="'relatedPersons'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Ortsbezüge (note[relatedPlaces])'"/>
							<xsl:call-template name="a037">
								<xsl:with-param name="p-type" select="'relatedPlaces'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Drucker (publisher)'"/>
							<xsl:call-template name="a037">
								<xsl:with-param name="p-type" select="'publisher'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--Monosyllaba-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Monosyllaba'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Monosyllaba</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zum <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-monosyllaba.html'"/>Monosyllabaregister</xsl:element></xsl:element>
				
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Monosyllaba (lg//monosyllabum)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Ausgezeichnet sind hexametrische Verse mit schließendem Einsilbler (Monosyllabum). Monosyllaba (monosyllabum) werden nur innerhalb von Gedichttexten (lg) untersucht. Angegeben werden die 10 Gedichte (div) mit den höchsten Werten a) absolut und b) im Verhältnis zur Gesamtversanzahl des Gedichts.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Monosyllaba ges.'"/>
							<xsl:value-of select="$countLgLMono"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachverteilung'"/>
							<xsl:call-template name="a019">
								<xsl:with-param name="p-type" select="'monosyllabum'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (absolut) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'monosyllabum'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (im Verhältnis zur Verszahl (l)) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'monosyllabum'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'ratio'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Spondiaci-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'Spondiaci'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Spondiaci</xsl:element>
				<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">Zum <xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0"><xsl:attribute name="type" select="'internal'"/><xsl:attribute name="subtype" select="'html'"/><xsl:attribute name="target" select="'register-spondiaci.html'"/>Spondiaciregister</xsl:element></xsl:element>
				
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Spondiaci (lg//spondaic)</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Ausgezeichnet sind hexametrische Verse mit spondeischem fünften Versfuß. Spondiaci (spondaic) werden nur innerhalb von Gedichttexten (lg) untersucht. Angegeben werden die 10 Gedichte (div) mit den höchsten Werten a) absolut und b) im Verhältnis zur Gesamtversanzahl des Gedichts.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Spondiaci ges.'"/>
							<xsl:value-of select="$countLgLSpon"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Sprachverteilung'"/>
							<xsl:call-template name="a019">
								<xsl:with-param name="p-type" select="'spondaic'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (absolut) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'spondaic'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (im Verhältnis zur Verszahl (l)) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'spondaic'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'ratio'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Versus tetracoli-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'versusTetracoli'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Versus tetracoli</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Versus tetracoli (lg/vt) [Mehrfachzählung möglich]</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Ausgezeichnet werden hexametrische Verse, die aus nur vier Wörtern bestehen. Versus tetracoli (vt) werden nur innerhalb vom Gedichttext (lg) untersucht. Ein Vers (l) kann ein versus tetracolus im griechischen und/oder lateinischen Sprachsegment sein (versusTetracoli4Grc|versusTetracoli5Grc|versusTetracoliLat). Im Griechischen kann es versus tetracoli mit 5 statt 4 Wörtern geben, wenn ein Kurzwort wie δ’ enthalten ist. Angegeben werden die Anzahl der Verse (l), die als tetracoli deklariert worden sind, bzw. die 10 Gedichte (div) mit den höchsten Werten a) absolut und b) im Verhältnis zur Gesamtversanzahl des Gedichts.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (l) mit vt (ges.)'"/>
							<xsl:value-of select="$countLgLVersusTetracoli"/>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (l) mit vt im Gr. (4 Wörter)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a030'"/>
								<xsl:with-param name="p-type" select="'versusTetracoli4Grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (l) mit vt im Gr. (5 Wörter)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a030'"/>
								<xsl:with-param name="p-type" select="'versusTetracoli5Grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Verse (l) mit vt im Lat. (4 Wörter)'"/>
							<xsl:call-template name="pattern-countType">
								<xsl:with-param name="p-countVar" select="'a030'"/>
								<xsl:with-param name="p-type" select="'versusTetracoliLat'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (absolut) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'vt'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'absolute'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'die meisten (im Verhältnis zur Verszahl (l)) (Top 10) in'"/>
							<xsl:call-template name="pattern-absoluteRatio">
								<xsl:with-param name="p-type" select="'vt'"/>
								<xsl:with-param name="p-minmax" select="'max'"/>
								<xsl:with-param name="p-absoluteRatio" select="'ratio'"/>
								<xsl:with-param name="p-top" select="'10'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Metrische Daten-->
			<!--.................................................................................-->
			<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="'MetrischeDaten'"/>
				<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Metrische Daten</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Zäsuren (back//list/item[metCaesuraPHGrc|...])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Metrische Daten sind im Apparat (back) pro Gedicht (list) zusammengestellt. Zäsuren (item) werden nur innerhalb von Gedichttexten (lg) untersucht. Unterschieden wird 1. nach Griechisch (Grc) und Latein (Lat) und 2. nach den Zäsurtypen "PH" (Penthemimeres), "KTT" (Kata triton trochaion) und "Other" (sonstige). Angegeben wird die Anzahl der Zäsuren.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<!--items werden im Template selbst generiert-->
						<xsl:call-template name="a032-i"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Zäsuren: die meisten (im Verhältnis zur Verszahl (l)) in</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Metrische Daten sind im Apparat (back) pro Gedicht (list) zusammengestellt. Zäsuren (item) werden nur innerhalb von Gedichttexten (lg) untersucht. Unterschieden wird 1. nach Griechisch (Grc) und Latein (Lat) und 2. nach den Zäsurtypen "PH" (Penthemimeres), "KTT" (Kata triton trochaion) und "Other" (sonstige). Angegeben werden die Gedichte (div) mit den höchsten Werten im Verhältnis zur Gesamtversanzahl des Gedichts.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<!--items werden im Template selbst generiert-->
						<xsl:call-template name="a033-i"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="div" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:element name="head" namespace="http://www.tei-c.org/ns/1.0">Hexameterschemata (back//list/item[metMetricalFootGrc|metMetricalFootLat])</xsl:element>
					<xsl:element name="p" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'altText'"/>
						<xsl:text>Metrische Daten sind im Apparat (back) pro Gedicht (list) zusammengestellt. Hexameterschemata (item) werden nur innerhalb von Gedichttexten (lg) untersucht. Unterschieden wird nach dem Vorkommen 1. nur im Griechischen, 2. nur im Lateinischen oder 3. sowohl im Griechischen als auch Lateinischen. Angegeben wird das Hexameterschema bzw. die Anzahl der Vorkommen. Angegeben wird die Verteilung von Daktylen (D) und Spondeen (S) in den ersten fünf Füßen hexametrischer Verse.</xsl:text>
					</xsl:element>
					<xsl:element name="list" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Varianten ges. (Gr.)'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a041'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Varianten ges. (Lat.)'"/>
							<xsl:call-template name="pattern-countSimple">
								<xsl:with-param name="p-countVar" select="'a042'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Vorkommen pro Variante (Gr.)'"/>
							<xsl:call-template name="a035">
								<xsl:with-param name="p-parent" select="'metMetricalFootGrc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Vorkommen pro Variante (Lat.)'"/>
							<xsl:call-template name="a035">
								<xsl:with-param name="p-parent" select="'metMetricalFootLat'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Varianten parallel im Gr. und Lat.'"/>
							<xsl:call-template name="a036">
								<xsl:with-param name="p-lang" select="'grc-la'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Varianten nur im Gr.'"/>
							<xsl:call-template name="a036">
								<xsl:with-param name="p-lang" select="'grc'"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="n" select="'Varianten nur im Lat.'"/>
							<xsl:call-template name="a036">
								<xsl:with-param name="p-lang" select="'la'"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<!--.................................................................................-->
			<!--Div. konkrete Fragen-->
			<!--.................................................................................-->
			<!--Ende Div-->
		</xsl:element>
	</xsl:template>
	<!--............................................................................................................................................................................-->
	<!--Analyse-Templates (für komplexere Analysen) -->
	<!--............................................................................................................................................................................-->
	<!-- Template-Benennung:
	- "a001" = Analyse-Template 001 (für komplexe, einmalige Berechnungen)
	- "pattern-[...]" = Gruppentemplate für einfache Berechnungen mit regelmäßigen Variablen (z.B. Elementname, @type-Werte etc.)
	- "ab-[...]" = generiert <ab> Element
	- "[...]-i" = generiert <item> Element
	- "[...]-t" = generiert <row>/<cell> Element(e)
	-->
	<xsl:template name="pattern-countSimple">
		<xsl:param name="p-countVar"/>
		<xsl:choose>
			<xsl:when test="$p-countVar = 'a001'">
				<xsl:value-of select="count($result//tei:TEI[descendant::tei:change[@type = 'hasTranscript']])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a003'">
				<xsl:value-of select="count($result//tei:TEI[not(descendant::tei:change[@type = 'hasTranscript'])])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a007'">
				<xsl:value-of select="count($result//tei:TEI//tei:sourceDesc/tei:*[@subtype = 'letter'])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a008'">
				<xsl:value-of select="count($result//tei:TEI//tei:sourceDesc/tei:*[not(@subtype)])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a017'">
				<xsl:value-of select="count($result//tei:lg//tei:quote[@subtype = 'complete' or @subtype = 'fragmentedStart' or @subtype = 'rangeStart'])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a023'">
				<xsl:value-of select="count(distinct-values($result//tei:note[@type = 'similia']//tei:ref[@type = 'external' and @subtype = 'similia' and tei:seg[@type = 'simAuthor' or @type = 'simAuthorSingle']]/tei:seg[@type = 'simAuthor' or @type = 'simAuthorSingle']/@n))"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a025'">
				<xsl:value-of select="count(distinct-values($result//tei:note[@type = 'similia']//tei:ref[@type = 'external' and @subtype = 'similia' and tei:seg[@type = 'simTitleSingle']]/tei:seg[@type = 'simTitleSingle']/@n))"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a041'">
				<xsl:value-of select="count($distValsHexameterGrc)"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a042'">
				<xsl:value-of select="count($distValsHexameterLat)"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="pattern-countType">
		<xsl:param name="p-countVar"/>
		<xsl:param name="p-type"/>
		<xsl:choose>
			<xsl:when test="$p-countVar = 'a004'">
				<!--manuscript|print|epigraphicInscription-->
				<xsl:value-of select="count($result//tei:TEI//tei:sourceDesc/tei:*[@type = $p-type])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a018'">
				<!--quote/@subtype= complete|rangeStart|fragmentedStart-->
				<xsl:value-of select="count($result//tei:lg//tei:quote[@subtype = $p-type])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a030'">
				<!--l/@ana="#versusTetracoliLat #versusTetracoli4Grc #versusTetracoli5Grc"-->
				<xsl:value-of select="count($result//tei:lg/tei:l[contains(@ana, $p-type)])"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="pattern-countLang">
		<!--lang = grc|la oder grc|grc-dor|la-->
		<xsl:param name="p-countVar"/>
		<xsl:param name="p-lang"/>
		<xsl:choose>
			<xsl:when test="$p-countVar = 'a012'">
				<xsl:value-of select="count($result//tei:lg/tei:l/tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang = $p-lang])"/>
			</xsl:when>
			<xsl:when test="$p-countVar = 'a016'">
				<xsl:value-of select="count($result//tei:lg/tei:l/tei:seg[not(@function) and @type = 'marginalia' and @xml:lang[contains(., $p-lang)]])"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="pattern-absoluteRatio">
		<!--Template zur Berechnung von absolute-|ratio-Werten-->
		<!--ruft auf: ab-absolute und ab-ratio-->
		<xsl:param name="p-type"/>
		<xsl:param name="p-minmax"/>
		<xsl:param name="p-absoluteRatio"/>
		<xsl:param name="p-subtype"/>
		<xsl:param name="p-top"/>
		<xsl:variable name="poems">
			<xsl:choose>
				<!--Neologismen-->
				<xsl:when test="$p-type = 'distinct'">
					<xsl:for-each select="$result//tei:div[@type = 'segment'][descendant::tei:distinct]">
						<xsl:variable name="file" select="substring-after(ancestor::tei:TEI//tei:title[@type = 'quoteInternal']/@sameAs, '#kt_')"/>
						<xsl:variable name="divNr" select="substring-after(@xml:id, 'd')"/>
						<xsl:variable name="count" select="count(tei:lg//tei:distinct)"/>
						<xsl:variable name="countL" select="count(tei:lg/tei:l)"/>
						<xsl:variable name="ratio" select="
								format-number(if ($countL > 0) then
									($count div $countL)
								else
									0, '0.00')"/>
						<xsl:variable name="percentage" select="
							format-number(if ($countL > 0) then
							(($count div $countL) * 100)
							else
							0, '0.00')"/>
						<xsl:choose>
							<xsl:when test="$p-absoluteRatio = 'absolute'">
								<xsl:call-template name="ab-absolute">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="$p-absoluteRatio = 'ratio'">
								<xsl:call-template name="ab-ratio">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
									<xsl:with-param name="p-countL" select="$countL"/>
									<xsl:with-param name="p-ratio" select="string($ratio)"/>
									<xsl:with-param name="p-percentage" select="string($percentage)"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
				<!--Versus Tetracoli-->
				<xsl:when test="$p-type = 'vt'">
					<xsl:for-each select="$result//tei:div[@type = 'segment'][descendant::tei:l[contains(@ana, '#versusTetracoli')]]">
						<xsl:variable name="file" select="substring-after(ancestor::tei:TEI//tei:title[@type = 'quoteInternal']/@sameAs, '#kt_')"/>
						<xsl:variable name="divNr" select="substring-after(@xml:id, 'd')"/>
						<xsl:variable name="count" select="count(tei:lg/tei:l[contains(@ana, '#versusTetracoli')])"/>
						<xsl:variable name="countL" select="count(tei:lg/tei:l)"/>
						<xsl:variable name="ratio" select="
								format-number(if ($countL > 0) then
									($count div $countL)
								else
									0, '0.00')"/>
						<xsl:variable name="percentage" select="
							format-number(if ($countL > 0) then
							(($count div $countL) * 100)
							else
							0, '0.00')"/>
						<xsl:choose>
							<xsl:when test="$p-absoluteRatio = 'absolute'">
								<xsl:call-template name="ab-absolute">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="$p-absoluteRatio = 'ratio'">
								<xsl:call-template name="ab-ratio">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
									<xsl:with-param name="p-countL" select="$countL"/>
									<xsl:with-param name="p-ratio" select="string($ratio)"/>
									<xsl:with-param name="p-percentage" select="string($percentage)"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
				<!--Similien-->
				<xsl:when test="$p-type = 'similia'">
					<!--Achtung: Similien-Refs befinden sich nicht in der div[xml:id=d1] sondern in back/list[corresp=#d1]-->
					<xsl:for-each select="$result//tei:div[@type = 'similiaNotes']/tei:list[descendant::tei:ref[@subtype = 'similia']]">
						<xsl:variable name="file" select="ancestor::tei:TEI/@xml:id"/>
						<xsl:variable name="divNr" select="substring-after(@corresp, '#d')"/>
						<xsl:variable name="correspDivID" select="'d' || $divNr"/>
						<xsl:variable name="countL" select="count(ancestor::tei:TEI//tei:div[@xml:id = $correspDivID]//descendant::tei:lg/tei:l)"/>
						<xsl:variable name="count" select="count(descendant::tei:ref[@type = $p-subtype][@subtype = 'similia'])"/>
						<xsl:variable name="ratio" select="
								format-number(if ($countL > 0) then
									($count div $countL)
								else
									0, '0.00')"/>
						<xsl:variable name="percentage" select="
							format-number(if ($countL > 0) then
							(($count div $countL) * 100)
							else
							0, '0.00')"/>
						<xsl:choose>
							<xsl:when test="$p-absoluteRatio = 'absolute'">
								<xsl:call-template name="ab-absolute">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="$p-absoluteRatio = 'ratio'">
								<xsl:call-template name="ab-ratio">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
									<xsl:with-param name="p-countL" select="$countL"/>
									<xsl:with-param name="p-ratio" select="string($ratio)"/>
									<xsl:with-param name="p-percentage" select="string($percentage)"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
				<!--Div (längstes/kürzestes Gedicht)-->
				<xsl:when test="$p-type = 'div'">
					<xsl:for-each select="$result//tei:div[@type = 'segment'][tei:lg]">
						<xsl:variable name="file" select="substring-after(ancestor::tei:TEI//tei:title[@type = 'quoteInternal']/@sameAs, '#kt_')"/>
						<xsl:variable name="divNr" select="substring-after(@xml:id, 'd')"/>
						<xsl:variable name="count" select="count(tei:lg/tei:l)"/>
						<xsl:call-template name="ab-absolute">
							<xsl:with-param name="p-file" select="$file"/>
							<xsl:with-param name="p-divNr" select="$divNr"/>
							<xsl:with-param name="p-count" select="$count"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:when>
				<!--Monosyllaba, Spondiaci-->
				<xsl:otherwise>
					<xsl:for-each select="$result//tei:div[@type = 'segment'][descendant::tei:seg[@type = $p-type]]">
						<xsl:variable name="file" select="substring-after(ancestor::tei:TEI//tei:title[@type = 'quoteInternal']/@sameAs, '#kt_')"/>
						<xsl:variable name="divNr" select="substring-after(@xml:id, 'd')"/>
						<xsl:variable name="count" select="count(tei:lg//tei:seg[@type = $p-type])"/>
						<xsl:variable name="countL" select="count(tei:lg/tei:l)"/>
						<xsl:variable name="ratio" select="
								format-number(if ($countL > 0) then
									($count div $countL)
								else
									0, '0.00')"/>
						<xsl:variable name="percentage" select="
							format-number(if ($countL > 0) then
							(($count div $countL) * 100)
							else
							0, '0.00')"/>
						<xsl:choose>
							<xsl:when test="$p-absoluteRatio = 'absolute'">
								<xsl:call-template name="ab-absolute">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="$p-absoluteRatio = 'ratio'">
								<xsl:call-template name="ab-ratio">
									<xsl:with-param name="p-file" select="$file"/>
									<xsl:with-param name="p-divNr" select="$divNr"/>
									<xsl:with-param name="p-count" select="$count"/>
									<xsl:with-param name="p-countL" select="$countL"/>
									<xsl:with-param name="p-ratio" select="string($ratio)"/>
									<xsl:with-param name="p-percentage" select="string($percentage)"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="maxRatio" select="max($poems//tei:num[@type = 'ratio'])"/>
		<xsl:variable name="minRatio" select="min($poems//tei:num[@type = 'ratio'])"/>
		<xsl:variable name="maxCount" select="max($poems//tei:num[@type = 'count'])"/>
		<xsl:variable name="minCount" select="min($poems//tei:num[@type = 'count'])"/>
		<xsl:choose>
			<xsl:when test="$p-absoluteRatio = 'absolute' and $p-minmax = 'max'">
				<xsl:for-each select="$poems/tei:ab">
					<xsl:sort select="number(tei:num[@type = 'count'])" data-type="number" order="descending"/>
					<xsl:if test="position() &lt;= number($p-top)">
						<xsl:copy-of select="."/>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$p-absoluteRatio = 'absolute' and $p-minmax = 'min'">
				<xsl:for-each select="$poems/tei:ab">
					<xsl:sort select="number(tei:num[@type = 'count'])" data-type="number" order="ascending"/>
					<xsl:if test="position() &lt;= number($p-top)">
						<xsl:copy-of select="."/>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$p-absoluteRatio = 'ratio' and $p-minmax = 'max'">
				<xsl:for-each select="$poems/tei:ab">
					<xsl:sort select="number(tei:num[@type = 'ratio'])" data-type="number" order="descending"/>
					<xsl:if test="position() &lt;= number($p-top)">
						<xsl:copy-of select="."/>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$p-absoluteRatio = 'ratio' and $p-minmax = 'min'">
				<xsl:for-each select="$poems/tei:ab">
					<xsl:sort select="number(tei:num[@type = 'ratio'])" data-type="number" order="ascending"/>
					<xsl:if test="position() &lt;= number($p-top)">
						<xsl:copy-of select="."/>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ab-absolute">
		<!--Aufgerufen von pattern-absoluteRatio-->
		<xsl:param name="p-count"/>
		<xsl:param name="p-file"/>
		<xsl:param name="p-divNr"/>
		<xsl:element name="ab" namespace="http://www.tei-c.org/ns/1.0">
			<xsl:attribute name="type" select="'poem'"/>
			<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'file'"/>
				<xsl:value-of select="$p-file"/>
			</xsl:element>
			<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'divNr'"/>
				<xsl:value-of select="$p-divNr"/>
			</xsl:element>
			<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'count'"/>
				<xsl:value-of select="$p-count"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ab-ratio">
		<!--Aufgerufen von pattern-absoluteRatio-->
		<xsl:param name="p-count"/>
		<xsl:param name="p-countL"/>
		<xsl:param name="p-ratio"/>
		<xsl:param name="p-percentage"/>
		<xsl:param name="p-file"/>
		<xsl:param name="p-divNr"/>
		<xsl:element name="ab" namespace="http://www.tei-c.org/ns/1.0">
			<xsl:attribute name="type" select="'poem'"/>
			<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'file'"/>
				<xsl:value-of select="$p-file"/>
			</xsl:element>
			<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'divNr'"/>
				<xsl:value-of select="$p-divNr"/>
			</xsl:element>
			<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'count'"/>
				<xsl:value-of select="$p-count"/>
			</xsl:element>
			<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'countL'"/>
				<xsl:value-of select="$p-countL"/>
			</xsl:element>
			<!--Ratio erstmal nicht mehr ausgeben, stattdessen Prozent (Ist aber in layout.css und xml2html.xsl noch angelegt)-->
			<!--<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'ratio'"/>
				<xsl:value-of select="$p-ratio"/>
			</xsl:element>-->
			<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'percentage'"/>
				<xsl:value-of select="$p-percentage"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="a011">
		<xsl:param name="p-lang"/>
		<xsl:if test="$p-lang = 'grc'">
			<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang[contains(., 'grc')]] and not(tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang = 'la'])])"/>
		</xsl:if>
		<xsl:if test="$p-lang = 'la'">
			<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang = 'la'] and not(tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang[contains(., 'grc')]])])"/>
		</xsl:if>
		<xsl:if test="$p-lang = 'grc-la'">
			<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang[contains(., 'grc')]] and tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang = 'la']])"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="a040">
		<xsl:param name="p-intExt"/>
		<!--ref
			- intern: @target="#d1..."
		 - extern: @target="Rhod...xml#d1..."-->
		<xsl:choose>
			<xsl:when test="$p-intExt = 'int'">
				<xsl:value-of select="count($result//tei:note[@type = 'similia']//tei:ref[@type = 'internal' and @subtype = 'similia'][matches(@target, '^#')])"/>
			</xsl:when>
			<xsl:when test="$p-intExt = 'ext'">
				<xsl:value-of select="count($result//tei:note[@type = 'similia']//tei:ref[@type = 'internal' and @subtype = 'similia'][matches(@target, '.xml')])"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="a013">
		<xsl:param name="p-lang"/>
		<xsl:param name="p-foreignLang"/>
		<xsl:param name="p-seg"/>
		<xsl:value-of select="count($result//tei:*[name() = $p-seg]/tei:l/tei:seg[not(@function) and not(@type = 'marginalia') and @xml:lang[contains(., $p-lang)] and descendant::tei:foreign[@xml:lang = $p-foreignLang]])"/>
	</xsl:template>
	<xsl:template name="a014">
		<xsl:param name="p-count"/>
		<xsl:if test="$p-count = 'seg'">
			<xsl:value-of select="count($result//tei:lg/tei:l/tei:seg[not(@function) and @type = 'marginalia'])"/>
		</xsl:if>
		<xsl:if test="$p-count = 'l'">
			<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[not(@function) and @type = 'marginalia']])"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="a015">
		<xsl:param name="p-lang"/>
		<xsl:param name="p-seg"/>
		<!--		
		einsprachig grc: mainText + seg/mainText=grc
		einsprachig la: mainText + seg/mainText=la
		zweisprachig grc: mainText + seg/mainText=grc ODER transMain + seg/transMain=grc
		zweisprachig la: mainText  + seg/mainText=la ODER transMain + seg/transMain=la
		zweisprachig grc+la: all 
		-->
		<xsl:variable name="count">
			<xsl:choose>
				<xsl:when test="$p-seg = 'single' and $p-lang = 'grc'">
					<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[contains(@xml:lang, 'grc')] and not(tei:seg[contains(@xml:lang, 'la')])]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'mainText'])"/>
				</xsl:when>
				<xsl:when test="$p-seg = 'single' and $p-lang = 'la'">
					<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[contains(@xml:lang, 'la')] and not(tei:seg[contains(@xml:lang, 'grc')])]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'mainText'])"/>
				</xsl:when>
				<xsl:when test="$p-seg = 'double' and $p-lang = 'grc'">
					<xsl:variable name="countMainText" select="count($result//tei:lg/tei:l[tei:seg[@type = 'mainText'][contains(@xml:lang, 'grc')] and tei:seg[contains(@xml:lang, 'la')]]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'mainText'])"/>
					<xsl:variable name="countTransMainText" select="count($result//tei:lg/tei:l[tei:seg[@type = 'translationOfMainText'][contains(@xml:lang, 'grc')] and tei:seg[contains(@xml:lang, 'la')]]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'translationOfMainText'])"/>
					<xsl:value-of select="$countMainText + $countTransMainText"/>
				</xsl:when>
				<xsl:when test="$p-seg = 'double' and $p-lang = 'la'">
					<xsl:variable name="countMainText" select="count($result//tei:lg/tei:l[tei:seg[@type = 'mainText'][contains(@xml:lang, 'la')] and tei:seg[contains(@xml:lang, 'grc')]]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'mainText'])"/>
					<xsl:variable name="countTransMainText" select="count($result//tei:lg/tei:l[tei:seg[@type = 'translationOfMainText'][contains(@xml:lang, 'la')] and tei:seg[contains(@xml:lang, 'grc')]]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'translationOfMainText'])"/>
					<xsl:value-of select="$countMainText + $countTransMainText"/>
				</xsl:when>
				<xsl:when test="$p-seg = 'double' and $p-lang = 'grc+la'">
					<xsl:value-of select="count($result//tei:lg/tei:l[tei:seg[contains(@xml:lang, 'grc')] and tei:seg[contains(@xml:lang, 'la')]]/tei:seg[not(@function) and @type = 'marginalia' and @subtype = 'all'])"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="$count"/>
	</xsl:template>
	<xsl:template name="a019">
		<xsl:param name="p-type"/>
		<xsl:variable name="countGrc">
			<xsl:choose>
				<xsl:when test="$p-type = 'distinct'">
					<xsl:value-of select="count($result//tei:lg//tei:seg[contains(@xml:lang, 'grc')]//tei:distinct)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count($result//tei:lg//tei:seg[contains(@xml:lang, 'grc')]//tei:seg[@type = $p-type])"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="countLat">
			<xsl:choose>
				<xsl:when test="$p-type = 'distinct'">
					<xsl:value-of select="count($result//tei:lg//tei:seg[contains(@xml:lang, 'la')]//tei:distinct)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count($result//tei:lg//tei:seg[contains(@xml:lang, 'la')]//tei:seg[@type = $p-type])"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="$countGrc || '&#160;(grc) ' || $countLat || '&#160;(la)'"/>
	</xsl:template>
	<xsl:template name="a022">
		<xsl:param name="p-qualifier"/>
		<xsl:param name="p-intExt"/>
		<xsl:value-of select="count($result//tei:note[@type = 'similia']//tei:ref[@type = $p-intExt and @subtype = 'similia' and tei:seg[@type = 'simQualifier' and @n = $p-qualifier]])"/>
	</xsl:template>
	<xsl:template name="a024">
		<xsl:param name="p-type"/>
		<xsl:variable name="valuesAll">
			<xsl:choose>
				<xsl:when test="$p-type = 'simAuthor'">
					<xsl:for-each select="$result//tei:note[@type = 'similia']//tei:ref[@type = 'external' and @subtype = 'similia' and (tei:seg[@type = 'simAuthor'] or tei:seg[@type = 'simAuthorSingle'])]">
						<xsl:value-of select="tei:seg[@type = 'simAuthor' or @type = 'simAuthorSingle']/@n"/>
						<xsl:text> </xsl:text>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$p-type = 'simTitle'">
					<xsl:for-each select="$result//tei:note[@type = 'similia']//tei:ref[@type = 'external' and @subtype = 'similia' and tei:seg[@type = 'simTitleSingle']]">
						<xsl:value-of select="tei:seg[@type = 'simTitleSingle']/@n"/>
						<xsl:text> </xsl:text>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$p-type = 'simAuthorTitle'">
					<xsl:for-each select="$result//tei:note[@type = 'similia']//tei:ref[@type = 'external' and @subtype = 'similia' and (tei:seg[@type = 'simAuthor'] and tei:seg[@type = 'simTitle'])]">
						<xsl:value-of select="tei:seg[@type = 'simAuthor']/@n"/>
						<xsl:text>+</xsl:text>
						<xsl:value-of select="tei:seg[@type = 'simTitle']/@n"/>
						<xsl:text> </xsl:text>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="groupAbs">
			<xsl:for-each select="distinct-values(tokenize($valuesAll, '\s+'))">
				<xsl:variable name="author">
					<xsl:choose>
						<xsl:when test="$p-type = 'simAuthor'">
							<xsl:value-of select="."/>
						</xsl:when>
						<xsl:when test="$p-type = 'simAuthorTitle'">
							<xsl:value-of select="substring-before(., '+')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="title">
					<xsl:choose>
						<xsl:when test="$p-type = 'simTitle'">
							<xsl:value-of select="."/>
						</xsl:when>
						<xsl:when test="$p-type = 'simAuthorTitle'">
							<xsl:value-of select="substring-after(., '+')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="count">
					<xsl:choose>
						<xsl:when test="$p-type = 'simAuthor'">
							<xsl:value-of select="count(tokenize($valuesAll, '\s+')[. = $author])"/>
						</xsl:when>
						<xsl:when test="$p-type = 'simTitle'">
							<xsl:value-of select="count(tokenize($valuesAll, '\s+')[. = $title])"/>
						</xsl:when>
						<xsl:when test="$p-type = 'simAuthorTitle'">
							<xsl:value-of select="count(tokenize($valuesAll, '\s+')[. = concat($author, '+', $title)])"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:element name="ab" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="type" select="'string'"/>
					<xsl:if test="string($author)">
						<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'name'"/>
							<xsl:value-of select="$author"/>
						</xsl:element>
					</xsl:if>
					<xsl:if test="string($title)">
						<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'title'"/>
							<xsl:value-of select="$title"/>
						</xsl:element>
					</xsl:if>
					<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'count'"/>
						<xsl:value-of select="$count"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:for-each select="$groupAbs/tei:ab">
			<xsl:sort select="tei:num" data-type="number" order="descending"/>
			<xsl:if test="position() &lt;= 10">
				<xsl:copy-of select="."/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="a028-t">
		<!--generiert (table) row/cell-->
		<xsl:param name="p-type"/>
		<xsl:for-each select="
				if ($p-type = 'literaryGenre') then
					$distValsGattung
				else
					if ($p-type = 'creativePeriod') then
						$distValsSchaffensphase
					else
						''">
			<!--variables-->
			<xsl:variable name="currentVal" select="."/>
			<xsl:variable name="countDistinct" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:distinct)"/>
			<xsl:variable name="countMono" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:seg[@type = 'monosyllabum'])"/>
			<xsl:variable name="countSpon" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:seg[@type = 'spondaic'])"/>
			<xsl:variable name="countVT" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:l[contains(@ana, '#versusTetracoli')])"/>
			<xsl:variable name="countQuote" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:quote[@subtype = 'complete' or @subtype = 'fragmentedStart' or @subtype = 'rangeStart'])"/>
			<xsl:variable name="countMarg" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:seg[@type = 'marginalia'])"/>
			<xsl:variable name="countRs" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg//tei:seg[not(@function) and not(@xml:lang = 'de')]//tei:rs)"/>
			<!--output-->
			<xsl:element name="row" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="role" select="'label'"/>
					<xsl:value-of select="$currentVal"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:variable name="countDivsProGattung" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]])"/>
					<xsl:value-of select="$countDivsProGattung"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:variable name="langs">
						<xsl:for-each select="$result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:metDecl/tei:note[@type = 'metDecl']/tei:list/tei:item">
							<xsl:element name="lang" namespace="http://www.tei-c.org/ns/1.0">
								<xsl:choose>
									<xsl:when test="descendant::tei:textLang[contains(@mainLang, 'grc')] and descendant::tei:textLang[contains(@mainLang, 'la')]">
										<xsl:text>grc-la</xsl:text>
									</xsl:when>
									<xsl:when test="descendant::tei:textLang[contains(@mainLang, 'grc')] and not(descendant::tei:textLang[contains(@mainLang, 'la')])">
										<xsl:text>grc</xsl:text>
									</xsl:when>
									<xsl:when test="descendant::tei:textLang[contains(@mainLang, 'la')] and not(descendant::tei:textLang[contains(@mainLang, 'grc')])">
										<xsl:text>la</xsl:text>
									</xsl:when>
								</xsl:choose>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="grc-la-count" select="count($langs/tei:lang[. = 'grc-la'])"/>
					<xsl:variable name="grc-count" select="count($langs/tei:lang[. = 'grc'])"/>
					<xsl:variable name="la-count" select="count($langs/tei:lang[. = 'la'])"/>
					<xsl:variable name="counts" as="map(*)">
						<xsl:map>
							<xsl:map-entry key="'grc-la'" select="$grc-la-count"/>
							<xsl:map-entry key="'grc'" select="$grc-count"/>
							<xsl:map-entry key="'la'" select="$la-count"/>
						</xsl:map>
					</xsl:variable>
					<xsl:for-each select="map:keys($counts)">
						<xsl:sort select="map:get($counts, .)" order="descending" data-type="number"/>
						<xsl:value-of select="map:get($counts, .) || '&#160;(' || . || ')&#160;'"/>
					</xsl:for-each>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:variable name="countList" as="xs:integer*">
						<xsl:for-each select="$result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:div[@type = 'segment']">
							<xsl:variable name="countL" select="count(descendant::tei:lg/tei:l)"/>
							<xsl:sequence select="$countL"/>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="maxCount" select="max($countList)"/>
					<xsl:variable name="minCount" select="min($countList)"/>
					<xsl:value-of select="$maxCount || '&#160;/&#160;' || $minCount"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:variable name="countAllL" select="count($result//tei:TEI[descendant::tei:textClass[@type = $p-type][descendant::tei:term = $currentVal]]//tei:lg/tei:l)"/>
					<xsl:value-of select="$countAllL"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countDistinct"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countMono"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countSpon"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countVT"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countQuote"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countMarg"/>
				</xsl:element>
				<xsl:element name="cell" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:value-of select="$countRs"/>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="a029">
		<xsl:param name="p-parent"/>
		<xsl:variable name="grouped-rs">
			<xsl:for-each-group select="
					if ($p-parent = 'hoc') then
						$result//tei:*[self::tei:head or self::tei:opener or self::tei:closer]//tei:rs[@type = 'index']
					else
						$result//tei:*[name() = $p-parent]//tei:rs[@type = 'index']" group-by="@ref">
				<xsl:element name="rs" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="value" select="current-grouping-key()"/>
					<xsl:attribute name="count" select="count(current-group())"/>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<xsl:variable name="sorted-rs" as="element()*">
			<xsl:perform-sort select="$grouped-rs/tei:rs">
				<xsl:sort select="@count" data-type="number" order="descending"/>
			</xsl:perform-sort>
		</xsl:variable>
		<xsl:for-each select="$sorted-rs[position() &lt;= 10]">
			<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="type" select="'string'"/>
				<xsl:value-of select="@value"/>
				<xsl:if test="@count != 1">
					<xsl:value-of select="'&#160;(' || @count || ')'"/>
				</xsl:if>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="a032-i">
		<!--generiert item-->
		<xsl:for-each select="$distValsMetCaesura">
			<xsl:variable name="currentVal" select="."/>
			<xsl:variable name="collectNumerics" select="$result//tei:back//tei:div[@type = 'metadataMetrics']//tei:item[@type = $currentVal]/tei:num[@type = 'cardinal']"/>
			<xsl:variable name="sumNumerics" select="sum($collectNumerics)"/>
			<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="."/>
				<xsl:value-of select="$sumNumerics"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="a033-i">
		<!--generiert item-->
		<xsl:for-each select="$distValsMetCaesura">
			<xsl:variable name="currentVal" select="."/>
			<xsl:variable name="collectNumerics" select="$result//tei:back//tei:div[@type = 'metadataMetrics']//tei:item[@type = $currentVal]/tei:num[@type = 'cardinal']"/>
			<xsl:variable name="maxVal" select="max($collectNumerics)"/>
			<xsl:variable name="poems">
				<xsl:for-each select="$result//tei:back//tei:div[@type = 'metadataMetrics']/tei:list">
					<!--pro Gedicht = list[corresp='#d1']-->
					<xsl:variable name="file" select="substring-after(ancestor::tei:TEI//tei:title[@type = 'quoteInternal']/@sameAs, '#kt_')"/>
					<xsl:variable name="divNr" select="substring-after(@corresp, '#d')"/>
					<xsl:variable name="correspDivId" select="substring-after(@corresp, '#')"/>
					<xsl:variable name="count" select="tei:item[@type = $currentVal]/tei:num[@type = 'cardinal']"/>
					<xsl:variable name="countL" select="count(ancestor::tei:TEI//tei:div[@type = 'segment' and @xml:id = $correspDivId]//tei:lg/tei:l)"/>
					<xsl:variable name="ratio" select="
							format-number(if ($countL > 0) then
								($count div $countL)
							else
								0, '0.00')"/>
					<xsl:variable name="percentage" select="
						format-number(if ($countL > 0) then
						(($count div $countL) * 100)
						else
						0, '0.00')"/>
					<xsl:call-template name="ab-ratio">
						<xsl:with-param name="p-file" select="$file"/>
						<xsl:with-param name="p-divNr" select="$divNr"/>
						<xsl:with-param name="p-count" select="$count"/>
						<xsl:with-param name="p-countL" select="$countL"/>
						<xsl:with-param name="p-ratio" select="string($ratio)"/>
						<xsl:with-param name="p-percentage" select="string($percentage)"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:variable>
			<xsl:element name="item" namespace="http://www.tei-c.org/ns/1.0">
				<xsl:attribute name="n" select="$currentVal"/>
				<xsl:for-each select="$poems/tei:ab[tei:num[@type = 'count'] = $maxVal]">
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="a035">
		<!--
		<item type="metMetricalFootGrc">
			<num type="numGroup" n="DDDDD">
				<num type="cardinal">75</num>
				<num type="ratio">28</num>
			</num>-->
		<xsl:param name="p-parent"/>
		<xsl:variable name="group-hexameter">
			<xsl:for-each select="
					if ($p-parent = 'metMetricalFootGrc') then
						$distValsHexameterGrc
					else
						$distValsHexameterLat">
				<xsl:variable name="currentVal" select="."/>
				<xsl:variable name="collectNumeric" select="$result//tei:item[@type = $p-parent]/tei:num[@n = $currentVal]/tei:num[@type = 'cardinal']"/>
				<xsl:variable name="sumCurrentValsNumerics" select="sum($collectNumeric)"/>
				<xsl:element name="ab" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="type" select="'string'"/>
					<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'string'"/>
						<xsl:value-of select="$currentVal"/>
					</xsl:element>
					<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'count'"/>
						<xsl:value-of select="$sumCurrentValsNumerics"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="sorted-hexameter" as="element()*">
			<xsl:perform-sort select="$group-hexameter/tei:ab">
				<xsl:sort select="tei:num" data-type="number" order="descending"/>
			</xsl:perform-sort>
		</xsl:variable>
		<xsl:copy-of select="$sorted-hexameter"/>
	</xsl:template>
	<xsl:template name="a036">
		<xsl:param name="p-lang"/>
		<!--Werte aus $distValsHexameterGrc|Lat in node() umwandeln, sonst klappt der Vergleich nicht-->
		<xsl:variable name="valuesGrc">
			<xsl:for-each select="$distValsHexameterGrc">
				<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="type" select="'string'"/>
					<xsl:value-of select="."/>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="valuesLat">
			<xsl:for-each select="$distValsHexameterLat">
				<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="type" select="'string'"/>
					<xsl:value-of select="."/>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:element name="ab" namespace="http://www.tei-c.org/ns/1.0">
			<xsl:attribute name="type" select="'string'"/>
			<xsl:choose>
				<xsl:when test="$p-lang = 'grc-la'">
					<xsl:for-each select="$valuesGrc/tei:string">
						<xsl:variable name="current" select="."/>
						<xsl:if test="$valuesLat/tei:string = $current">
							<xsl:copy-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$p-lang = 'grc'">
					<xsl:for-each select="$valuesGrc/tei:string">
						<xsl:variable name="current" select="."/>
						<xsl:if test="not($valuesLat/tei:string = $current)">
							<xsl:copy-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$p-lang = 'la'">
					<xsl:for-each select="$valuesLat/tei:string">
						<xsl:variable name="current" select="."/>
						<xsl:if test="not($valuesGrc/tei:string = $current)">
							<xsl:copy-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<xsl:template name="a037">
		<xsl:param name="p-type"/>
		<xsl:variable name="refs">
			<xsl:choose>
				<xsl:when test="$p-type = 'dedication'">
					<xsl:for-each-group select="$result//tei:teiHeader//tei:provenance[@type = 'dedication']//tei:rs[string(@ref)]" group-by="@ref">
						<xsl:sort select="current-grouping-key()"/>
						<xsl:variable name="count" select="count($result//tei:teiHeader//tei:provenance[@type = 'dedication']//tei:rs[@ref = current-grouping-key()])"/>
						<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'string'"/>
							<xsl:value-of select="current-grouping-key()"/>
							<xsl:if test="$count != 1">
								<xsl:value-of select="'&#160;(' || $count || ')'"/>
							</xsl:if>
						</xsl:element>
					</xsl:for-each-group>
				</xsl:when>
				<xsl:when test="$p-type = 'relatedPersons'">
					<xsl:for-each-group select="$result//tei:teiHeader//tei:note[@type = 'relatedPersons']//tei:rs[string(@ref)]" group-by="@ref">
						<xsl:sort select="current-grouping-key()"/>
						<xsl:variable name="count" select="count($result//tei:teiHeader//tei:note[@type = 'relatedPersons']//tei:rs[@ref = current-grouping-key()])"/>
						<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'string'"/>
							<xsl:value-of select="current-grouping-key()"/>
							<xsl:if test="$count != 1">
								<xsl:value-of select="'&#160;(' || $count || ')'"/>
							</xsl:if>
						</xsl:element>
					</xsl:for-each-group>
				</xsl:when>
				<xsl:when test="$p-type = 'relatedPlaces'">
					<xsl:for-each-group select="$result//tei:teiHeader//tei:note[@type = 'relatedPlaces']//tei:rs[string(@ref)]" group-by="@ref">
						<xsl:sort select="current-grouping-key()"/>
						<xsl:variable name="count" select="count($result//tei:teiHeader//tei:note[@type = 'relatedPlaces']//tei:rs[@ref = current-grouping-key()])"/>
						<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'string'"/>
							<xsl:value-of select="current-grouping-key()"/>
							<xsl:if test="$count != 1">
								<xsl:value-of select="'&#160;(' || $count || ')'"/>
							</xsl:if>
						</xsl:element>
					</xsl:for-each-group>
				</xsl:when>
				<xsl:when test="$p-type = 'publisher'">
					<xsl:for-each-group select="$result//tei:teiHeader//tei:publisher//tei:rs[string(@ref)]" group-by="@ref">
						<xsl:sort select="current-grouping-key()"/>
						<xsl:variable name="count" select="count($result//tei:teiHeader//tei:publisher//tei:rs[@ref = current-grouping-key()])"/>
						<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'string'"/>
							<xsl:value-of select="current-grouping-key()"/>
							<xsl:if test="$count != 1">
								<xsl:value-of select="'&#160;(' || $count || ')'"/>
							</xsl:if>
						</xsl:element>
					</xsl:for-each-group>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$refs"/>
	</xsl:template>
	<xsl:template name="a039">
		<xsl:param name="p-type"/>
		<xsl:param name="p-minMax"/>
		<!--Einheit / Gedicht: 
		<ref target="Rhod.Coc.Ion.1-2.xml#d1..." sameAs="#kt_Rhod.Coc.Ion.1" ...>
		- @target = Einheit [aus Dateinamen extrahieren]
		- @sameAs = Gedichtnr. [aus Kurztitel extrahieren]
		-->
		<!--Erst alle refs zusammenziehen und vorverarbeiten, weil bei Referenzen innerhalb derselben Datei die Datei-Angabe in @target fehlt (beginnt direkt mit #)-->
		<xsl:variable name="refs">
			<xsl:for-each select="$result//tei:note[@type = 'similia']//tei:ref[@type = 'internal' and @subtype = 'similia']">
				<xsl:element name="ref" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="target" select="
							if (matches(@target, '^#')) then
								ancestor::tei:TEI/@xml:id
							else
								substring-before(@target, '.xml')"/>
					<xsl:attribute name="sameAs" select="substring-after(@sameAs, '#kt_')"/>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="listRefsMost">
			<xsl:variable name="groupedRefs">
				<xsl:for-each-group select="$refs/tei:ref" group-by="
						if ($p-type = 'target') then
							@target
						else
							@sameAs">
					<xsl:element name="value" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="value" select="current-grouping-key()"/>
						<xsl:attribute name="count" select="count(current-group())"/>
					</xsl:element>
				</xsl:for-each-group>
			</xsl:variable>
			<xsl:variable name="sortedRefs">
				<xsl:perform-sort select="$groupedRefs/tei:value">
					<xsl:sort select="@count" data-type="number" order="descending"/>
				</xsl:perform-sort>
			</xsl:variable>
			<xsl:for-each select="$sortedRefs/tei:value[position() &lt;= 10]">
				<xsl:element name="ab" namespace="http://www.tei-c.org/ns/1.0">
					<xsl:attribute name="type" select="'poem'"/>
					<xsl:element name="string" namespace="http://www.tei-c.org/ns/1.0">
						<xsl:attribute name="type" select="'file'"/>
						<xsl:value-of select="@value"/>
					</xsl:element>
					<xsl:if test="@count != 1">
						<xsl:element name="num" namespace="http://www.tei-c.org/ns/1.0">
							<xsl:attribute name="type" select="'count'"/>
							<xsl:value-of select="@count"/>
						</xsl:element>
					</xsl:if>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$p-type = 'target' and not($p-minMax)">
				<xsl:value-of select="count(distinct-values($refs/tei:ref/@target))"/>
			</xsl:when>
			<xsl:when test="$p-type = 'sameAs' and not($p-minMax)">
				<xsl:value-of select="count(distinct-values($refs/tei:ref/@sameAs))"/>
			</xsl:when>
			<xsl:when test="$p-type = 'target' and $p-minMax">
				<xsl:copy-of select="$listRefsMost"/>
			</xsl:when>
			<xsl:when test="$p-type = 'sameAs' and $p-minMax">
				<xsl:copy-of select="$listRefsMost"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
